%def_with mysql
%def_with ssl
%def_with ldap
%def_with memcache
%def_with lua
%def_with gamin

%define lighttpd_user lighttpd
%define lighttpd_group lighttpd
%define lighttpd_spool %_spooldir/%name

%define spawn_fcgi_user _spawn_fcgi
%define spawn_fcgi_group _spawn_fcgi

%define docdir %_docdir/%name-%version-doc
%define svnrev 2299

Name: lighttpd
Version: 1.4.20
Release: alt0.M41.1

Summary: A fast webserver with minimal memory-footprint
License: BSD
Group: System/Servers

# git svn init -Ttrunk -ttags -bbranches svn://svn.lighttpd.net/lighttpd/
Url: http://www.lighttpd.net
Packager: Vladimir V Kamarzin <vvk@altlinux.ru>

Source0: lighttpd.tar

Requires(pre): shadow-utils
Provides: webserver

# Automatically added by buildreq on Wed Nov 02 2005
BuildRequires: bzlib-devel gcc-c++ libfcgi-devel libpcre-devel libstdc++-devel perl-devel zlib-devel

%{?_with_mysql:BuildPreReq: libMySQL-devel}
%{?_with_ssl:BuildPreReq: libssl-devel}
%{?_with_ldap:BuildPreReq: libldap-devel}
%{?_with_memcache:BuildPreReq: libmemcache-devel}
%{?_with_lua:BuildPreReq:liblua5-devel}
%{?_with_gamin:BuildPreReq: pkg-config gamin-devel}

%description
%name is intented to be a frontend for ad-servers which have to deliver
small files concurrently to many connections.

%package mysql-vhost
Summary: MySQL based vhosting %name module
Group: System/Servers
Requires: %name = %version-%release

%description mysql-vhost
This module provides virtual hosts (vhosts) based on a MySQL table.

%package cml
Summary: CML (Cache Meta Language) %name module
Group: System/Servers
Requires: %name = %version-%release

%description cml
CML is a Meta language to describe the dependencies of a page at one side and
building a page from its fragments on the other side using LUA. 

%package trigger_b4_dl
Summary: another anti hot-linking %name module
Group: System/Servers
Requires: %name = %version-%release

%description trigger_b4_dl
another anti hot-linking module.

%package rrdtool
Summary: rrdtool support %name module
Group: System/Servers
Requires: %name = %version-%release, rrdtool

%description rrdtool
mod_rrdtool is used to monitor the traffic and load on the webserver.

%package doc
Summary: %name documentation
Group: Documentation

%description doc
Documentation for %name.

%package -n spawn-fcgi
Summary: Spawn remote FastCGI processes
Group: System/Servers

%description -n spawn-fcgi
Spawn-fcgi is used to spawn remote FastCGI processes.

%prep
%setup -q -n %name
%autoreconf

%build
%configure --libdir=%_libdir/%name \
    %{?_with_mysql:       --with-mysql} \
    %{?_with_ssl:         --with-openssl} \
    %{?_with_ldap:	  --with-ldap} \
    %{?_with_memcache:	  --with-memcache} \
    %{?_with_lua:	  --with-lua} \
    %{?_with_gamin:	  --with-fam} \
    %{?_with_lua:	  LUA_CFLAGS="-I/usr/include/" LUA_LIBS="-llua -llualib"}
%make_build

# run tests for sanity checks
#pushd tests
#./wrapper.sh . .. ./prepare.sh
#./wrapper.sh . .. ./run-tests.pl
#popd

%install
%makeinstall libdir=%buildroot%_libdir/%name

mkdir -p %buildroot%_sysconfdir/{rc.d/init.d,sysconfig,%name}
mkdir -p %buildroot{%_spooldir/%name/tmp,%_var/log/%name}
install -m755 %name.init %buildroot%_initdir/%name
install -m644 doc/sysconfig.lighttpd %buildroot%_sysconfdir/sysconfig/lighttpd
install -m644 doc/lighttpd.conf %buildroot%_sysconfdir/%name/%name.conf

mkdir -p %buildroot%_var/run/spawn-fcgi
install -m755 spawn-fcgi.init %buildroot%_initdir/spawn-fcgi
install -m644 spawn-fcgi.sysconfig %buildroot%_sysconfdir/sysconfig/spawn-fcgi

# logrotate script
install -pDm644 lighttpd.logrotate %buildroot%_sysconfdir/logrotate.d/%name

rm -rf %buildroot%docdir
mkdir -p %buildroot%docdir
cp -a ChangeLog doc/lighttpd.conf doc/lighttpd.user doc/*.txt %buildroot%docdir/
bzip2 -9 %buildroot%docdir/ChangeLog

%pre
%_sbindir/groupadd -r -f %lighttpd_group ||:
%_sbindir/useradd -r -g %lighttpd_group -d /dev/null -s /dev/null -n %lighttpd_user \
	2> /dev/null > /dev/null ||:

%pre -n spawn-fcgi
%_sbindir/groupadd -r -f %spawn_fcgi_group ||:
%_sbindir/useradd -r -g %spawn_fcgi_group -d /dev/null -s /dev/null -n %spawn_fcgi_user \
        2> /dev/null > /dev/null ||:

%post
%post_service lighttpd

%preun
%preun_service lighttpd

%post -n spawn-fcgi
%post_service spawn-fcgi

%preun -n spawn-fcgi
%preun_service spawn-fcgi

%files
%doc README INSTALL COPYING AUTHORS
%_initdir/%name
%config(noreplace) %_sysconfdir/sysconfig/lighttpd
%config(noreplace) %attr(0750,root,%lighttpd_group) %_sysconfdir/%name
%config(noreplace) %_sysconfdir/logrotate.d/%name
%_man1dir/*
%exclude %_man1dir/spawn-fcgi*
%dir %attr(1770,root,%lighttpd_group) %lighttpd_spool
%dir %attr(1770,root,%lighttpd_group) %lighttpd_spool/tmp
%dir %attr(1770,root,%lighttpd_group) %_var/log/%name
%dir %_libdir/%name
%_libdir/%name/*.so
%if_with mysql
%exclude %_libdir/%name/*_mysql_vhost.so
%endif #mysql
%if_with lua
%exclude %_libdir/%name/*_cml.so
%endif #cml
%if_with memcache
%exclude %_libdir/%name/*_trigger_b4_dl.so
%endif #trigger_b4_dl
%exclude %_libdir/%name/*_rrdtool.so
%_sbindir/*
%_bindir/*
%exclude %_bindir/spawn-fcgi
%exclude %_libdir/%name/*.la

%files doc
%docdir

%files -n spawn-fcgi
%_bindir/spawn-fcgi
%_man1dir/spawn-fcgi*
%config(noreplace) %_sysconfdir/sysconfig/spawn-fcgi
%_initdir/spawn-fcgi
%dir %attr(1770,root,%spawn_fcgi_group) %_var/run/spawn-fcgi

%if_with mysql
%files mysql-vhost
%_libdir/%name/*mysql_vhost.so
%endif #mysql

%if_with lua
%files cml
%_libdir/%name/*cml.so
%endif lua

%if_with memcache
%files trigger_b4_dl
%_libdir/%name/*trigger_b4_dl.so
%endif #memcache

%files rrdtool
%_libdir/%name/*rrdtool.so

%changelog
* Tue Sep 30 2008 Vladimir V. Kamarzin <vvk@altlinux.org> 1.4.20-alt0.M41.1
- Rebuild for 4.1

* Tue Sep 30 2008 Vladimir V. Kamarzin <vvk@altlinux.org> 1.4.20-alt1
- 1.4.20 release
- Security fix: duplicate Request Headers Memory Leak Vulnerability
  http://secunia.com/advisories/32069/

* Tue Sep 09 2008 Vladimir V. Kamarzin <vvk@altlinux.org> 1.4.19-alt6.svn.2299
- Updated to 2299 revision of 1.4.x branch
- Move spawn-fcgi to separate subpackage (thresh, vvk)

* Wed Aug 27 2008 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.19-alt5.svn.2296
- Updated to 2296 revision of 1.4.x branch
- initscript: add restart() (Closes: #16417)
- logrotate-script: redirect output to /dev/null

* Fri Apr 04 2008 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.19-alt4.svn.2142
- Updated to 2142 revision of 1.4.x branch
- Security fixes:
  + CVE-2008-1531 lighttpd OpenSSL Error Queue Denial of Service Vulnerability
- Enable memcache support

* Fri Mar 14 2008 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.19-alt3
- Add logrotate script
- Initscript changes:
  + Check docdir existance and create it if it doesn't exist (Closes: #12725)
  + Introduce log_reopen() function for sending SIGHUP to daemon - needed for
  log rotation

* Tue Mar 11 2008 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.19-alt2
- There is an error in previous package version: real version was 1.4.18, not
  1.4.19!
- This is real 1.4.19 release. Security fixes:
  + CVE-2008-0983: remote DoS
  + CVE-2008-1111: exposure of sensitive information (Fix sending source of cgi
  script instead of 500 error if fork fails)

* Tue Sep 11 2007 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.19-alt1
- Real version is 1.4.18 - there is error in package version!!!
- Security fix: CVE-2007-4727: FastCGI header overrun in mod_fastcgi

* Tue Sep 04 2007 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.18-alt1.svn.1981
- Updated to 1981 revision of 1.4.x branch:
  + many bugs fixed (see HISTORY)
- Fixed ALT Security Policy violation (spooldir permissions)

* Mon Jul 16 2007 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.15-alt2.svn.1881
- Updated to 1881 revision of 1.4.x branch
- Security fixes:
  + Remote crash on duplicate header keys with line-wrapping (fixes #1230)
  + Missing check for base64 encoded string in mod_auth and Basic
    auth (reported by Stefan Esser)
  + Crash with md5-sess and cnonce not set in mod_auth (reported
    by Stefan Esser)
  + Possible crash in Auth-Digest header parser on trailing WS in
    mod_auth (reported by Stefan Esser)
  + mem-leak in mod_auth (reported by Stefan Esser)
  + URL Access restrictions bypass in mod_access
  + Local DOS with broken FastCGI applications

* Mon Apr 16 2007 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.15-alt1
- Updated to 1.4.15 release

* Thu Apr 12 2007 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.13-alt3.1745
- Updated to 1745 revision of 1.4.x branch
- Added sis/sisx mime types (Closes: #11462)

* Thu Apr 05 2007 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.13-alt2.1719
- Updated to 1719 revision of 1.4.x branch
  + Fix crash if gethostbyaddr() fails on redirect

* Sat Mar 24 2007 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.13-alt2.1716
- Build without memcache

* Tue Mar 20 2007 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.13-alt1.1716
- Updated to 1716 revision of 1.4.x branch

* Thu Feb 08 2007 Vladimir V Kamarzin <vvk@altlinux.ru> 1.4.13-alt1.1607
- Updated to 1.4.x branch svn revision 1607
- Security fix:
  + Fix remote DOS in CRLF parsing (CVE-2007-1869)
  + Fix a crash for files with an mtime of 0 reported by cubiq on irc
  (CVE-2007-1870)
- Integrate lighttpd-1.4.3-config.patch

* Mon Jan 30 2006 LAKostis <lakostis at altlinux.org> 1.4.9-alt1
- 1.4.9;
- change fam support to gamin;
- pack ChangeLog and move it to -doc subpackage.

* Sat Jan 07 2006 LAKostis <lakostis at altlinux.org> 1.4.8-alt1
- 1.4.8;
- fix #8431.

* Sat Oct 29 2005 LAKostis <lakostis at altlinux.org> 1.4.6-alt1
- 1.4.6.
- fix config dir permissions.
- fix requires.
- add libfcgi-devel to BuildRequires.
- add lua,memcache,fam,ldap support.
- split out to many packages.

* Sun Sep 11 2005 LAKostis <lakostis at altlinux.org> 1.4.3-alt1
- first build for ALTLinux Sisyphus.

* Thu Sep 30 2004 12:41 <jan@kneschke.de> 1.3.1
- upgraded to 1.3.1

* Tue Jun 29 2004 17:26 <jan@kneschke.de> 1.2.3
- rpmlint'ed the package
- added URL
- added (noreplace) to start-script
- change group to Networking/Daemon (like apache)

* Sun Feb 23 2003 15:04 <jan@kneschke.de>
- initial version
